"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.boot = exports.name = void 0;
require("./interface");
const addPlugin_1 = require("./api/addPlugin");
const setOptions_1 = require("./api/setOptions");
const addPreset_1 = require("./api/addPreset");
const setPresets_1 = require("./api/setPresets");
/**
 * Extension ident
 */
exports.name = '@roots/bud-babel';
/**
 * Register babel
 */
const boot = (app) => {
    Object.assign(app, {
        /**
         * Babel config object.
         */
        babel: {
            /**
             * Set transform/loader options.
             */
            setOptions: setOptions_1.setOptions.bind(app),
            /**
             * Plugins.
             */
            addPlugin: addPlugin_1.addPlugin.bind(app),
            /**
             * Presets.
             */
            addPreset: addPreset_1.addPreset.bind(app),
            /**
             * Set presets
             */
            setPresets: setPresets_1.setPresets.bind(app),
        },
    });
    app.build
        .set('loaders.babel', require.resolve('babel-loader'))
        .set('items.babel', {
        loader: app.build.get('loaders.babel'),
        options: {
            presets: [],
            plugins: [],
        },
    })
        .mutate('rules.js.use', () => [
        app.build.access('items.cache'),
        app.build.access('items.thread'),
        app.build.access('items.babel'),
    ]);
    app.babel
        .addPreset('@babel/preset-env')
        .babel.addPlugin('@babel/plugin-transform-runtime', {
        helpers: false,
    })
        .babel.setOptions({
        root: app.project(),
        cacheDirectory: app.project(app.store.get('locations.storage')),
    });
};
exports.boot = boot;
//# sourceMappingURL=index.js.map